# Test the component which wraps the alert library's subscribe
# mechanism.

# from alert_lib import *



import unittest
from pipevis import AlertSource

class FakeSnarf(object):
    def __init__(self, callback, origin, channel):
        self._callback = callback
        self._origin = origin
        self._channel = channel
        self._stopped = False
    def test_is_stopped(self): return self._stopped
    def stop(self):
        self._stopped = True
    


class TestAlertSource(unittest.TestCase):
    def test_basic(self):
        origin = "foo"
        channel_name = "bar"

        fake_snarf = [None]
        def snarf_factory(callback, origin, channel):
            fake_snarf[0] = FakeSnarf(callback, origin, channel)
            return fake_snarf[0]
        
        src = AlertSource(alert_factory=snarf_factory,
                          callback=lambda _: None,
                          origin=origin,
                          channel_name=channel_name)

        # Haven't created the snarf sink yet
        self.assertEquals(fake_snarf[0], None)

        src.start()

        # Now we have...
        self.assertTrue(isinstance(fake_snarf[0], FakeSnarf))
        # ...but it hasn't been stopped yet
        self.assertFalse(fake_snarf[0].test_is_stopped())

        src.stop()

        # Now it's stopped
        self.assertTrue(fake_snarf[0].test_is_stopped())
            

if __name__ == '__main__':
    unittest.main()
